documentationtools.InheritanceGraph
===================================

.. abjad-lineage:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph

.. autoclass:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.addresses
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.child_parents_mapping
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.graphviz_format
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.graphviz_graph
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.immediate_classes
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_addresses
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_classes
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_distance_mapping
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_prune_distance
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.parent_children_mapping
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.recurse_into_submodules
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.root_addresses
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.root_classes
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.use_clusters
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.use_groups
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__eq__
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__format__
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__ne__
      ~abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.addresses
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.child_parents_mapping
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.immediate_classes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_addresses
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_classes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_distance_mapping
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.lineage_prune_distance
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.parent_children_mapping
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.recurse_into_submodules
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.root_addresses
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.root_classes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.use_clusters
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.use_groups
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.InheritanceGraph.InheritanceGraph.__repr__
   :noindex:
